searchData={"items":[{"type":"module","title":"HTML2Text","doc":"A native-implemented HTML to plain text converter using Rust NIF.\n\nThis module provides functionality to convert HTML documents to plain text format\nwith configurable line width wrapping. It uses the Rust `html2text` crate under\nthe hood for high-performance HTML parsing and text extraction.\n\nThe converter handles HTML entities, removes tags, and formats the output as\nreadable plain text while preserving the logical structure of the content.\n\nSee: https://github.com/jugglerchris/rust-html2text","ref":"HTML2Text.html"},{"type":"function","title":"HTML2Text.convert/2","doc":"Converts HTML content to plain text.","ref":"HTML2Text.html#convert/2"},{"type":"function","title":"Options - HTML2Text.convert/2","doc":"- `:width` — Maximum line width (positive integer or `:infinity`). Defaults to `80`. Setting to `:infinity` disables line wrapping and outputs the entire text on a single line.\n- `:decorate` — Enables text decorations like bold or italic. Boolean, defaults to `true`. When `false`, output is plain text without styling.\n- `:link_footnotes` — Adds numbered link footnotes at the end of the text. Boolean, defaults to `true`. When `false`, links are omitted.\n- `:table_borders` — Shows ASCII borders around table cells. Boolean, defaults to `true`. When `false`, tables render without borders.\n- `:pad_block_width` — Pads blocks with spaces to align text to full width. Boolean, defaults to `false`. Useful for fixed-width layouts.\n- `:allow_width_overflow` — Allows lines to exceed the specified width if wrapping is impossible. Boolean, defaults to `false`. Prevents errors when content can't fit.\n- `:min_wrap_width` — Minimum length of text chunks when wrapping lines. Integer ≥ 1, defaults to `3`. Helps avoid awkwardly narrow wraps.\n- `:raw` — Enables raw mode with minimal processing and formatting. Boolean, defaults to `false`. Produces plain, raw text output.\n- `:wrap_links` — Wraps long URLs or links onto multiple lines. Boolean, defaults to `true`. When `false`, links stay on a single line and may overflow.\n- `:unicode_strikeout` — Uses Unicode characters for strikeout text. Boolean, defaults to `true`. When `false`, strikeout renders in simpler styles.","ref":"HTML2Text.html#convert/2-options"},{"type":"function","title":"Examples - HTML2Text.convert/2","doc":"iex> html = \" Title  Some paragraph text. \"\n    ...> HTML2Text.convert(html, width: 15)\n    {:ok, \"# Title\\n\\nSome paragraph\\ntext.\\n\"}\n\n    iex> HTML2Text.convert(\" Important \", decorate: false)\n    {:ok, \"Important\\n\"}\n\n    iex> HTML2Text.convert(\"   A  B   \", [])\n    {:ok, \"─┬─\\nA│B\\n─┴─\\n\"}","ref":"HTML2Text.html#convert/2-examples"},{"type":"function","title":"HTML2Text.convert!/2","doc":"Converts HTML content to plain text, raising on failure.\n\nThis function behaves like `convert/2`, but raises an error if conversion fails.","ref":"HTML2Text.html#convert!/2"},{"type":"type","title":"HTML2Text.opts/0","doc":"","ref":"HTML2Text.html#t:opts/0"},{"type":"extras","title":"README","doc":"# HTML2Text\n[![Hex.pm](https://img.shields.io/hexpm/v/html2text.svg)](https://hex.pm/packages/html2text)\n\nA high-performance Elixir library for converting HTML documents to plain text format using Rust NIFs (Native Implemented Functions).","ref":"readme.html"},{"type":"extras","title":"Overview - README","doc":"HTML2Text provides a simple and efficient way to extract readable plain text from HTML content. It leverages the power of Rust's [html2text](https://crates.io/crates/html2text) crate to deliver fast HTML parsing and text extraction while maintaining the logical structure and readability of the content.","ref":"readme.html#overview"},{"type":"extras","title":"Installation - README","doc":"Add `html2text` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:html2text, \"~> 0.2\"}\n  ]\nend\n```\n\nThen run:\n\n```bash\nmix deps.get\n```","ref":"readme.html#installation"},{"type":"extras","title":"Usage - README","doc":"```elixir\n# Convert with specific line width\nhtml = \" Welcome  This is a sample paragraph with some content. \"\ntext = HTML2Text.convert!(html, width: 30)\nIO.puts(text)\n\n# Output:\n# # Welcome\n#\n# This is a sample paragraph\n# with some content.\n\nhtml = \"\"\"\n \n   Article Title \n    Introduction:  This article covers important topics. \n\n   Section 1 \n   Content with  emphasis  and  links . \n\n   \n     Point one \n     Point two \n   \n\n   Section 2: Simple Table \n   Key metrics overview: \n\n   \n     \n       \n         Metric \n         Value \n         Change \n       \n     \n     \n       \n         Users \n         15,300 \n         +12% \n       \n       \n         Sessions \n         48,500 \n         -5% \n       \n     \n   \n\n   Conclusion \n   This article provided an overview of important web technologies and some key statistics. \n \n\"\"\"\n\ntext = HTML2Text.convert!(html)\nIO.puts(text)\n\n# Output:\n# # Article Title\n#\n# **Introduction:** This article covers important topics.\n#\n#","ref":"readme.html#usage"},{"type":"extras","title":"Section 1 - README","doc":"#\n# Content with *emphasis* and [links][1].\n# * Point one\n# * Point two\n#\n#","ref":"readme.html#section-1"},{"type":"extras","title":"Section 2: Simple Table - README","doc":"#\n# Key metrics overview:\n#\n# ────────┬──────┬──────\n# Metric  │Value │Change\n# ────────┼──────┼──────\n# Users   │15,300│+12%  \n# ────────┼──────┼──────\n# Sessions│48,500│-5%   \n# ────────┴──────┴──────\n#\n#","ref":"readme.html#section-2-simple-table"},{"type":"extras","title":"Conclusion - README","doc":"#\n# This article provided an overview of important web technologies and some key\n# statistics.\n#\n# [1]: http://example.com\n```","ref":"readme.html#conclusion"}],"proglang":"elixir","content_type":"text/markdown","producer":{"name":"ex_doc","version":"0.38.2"}}